==> sitespeedio-33.6.0-x86_64-1cf.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf sitespeed.io )
( cd usr/bin ; ln -sf ../lib64/node_modules/sitespeed.io/bin/sitespeed.js sitespeed.io )
( cd usr/bin ; rm -rf sitespeed.io-wpr )
( cd usr/bin ; ln -sf ../lib64/node_modules/sitespeed.io/bin/browsertimeWebPageReplay.js sitespeed.io-wpr )
( cd usr/lib64/node_modules/root/node_modules/.bin ; rm -rf network-address )
( cd usr/lib64/node_modules/root/node_modules/.bin ; ln -sf ../network-address/cli.js network-address )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf acorn )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../acorn/bin/acorn acorn )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf adbkit )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../@devicefarmer/adbkit/bin/adbkit adbkit )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf browsertime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../browsertime/bin/browsertime.js browsertime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf btoa )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../btoa/bin/btoa.js btoa )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf chrome-remote-interface )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../chrome-remote-interface/bin/client.js chrome-remote-interface )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf crawl )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../simplecrawler/lib/cli.js crawl )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf gp12-pem )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../google-p12-pem/build/src/bin/gp12-pem.js gp12-pem )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf ignored )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../dotignore/bin/ignored ignored )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf markdown-it )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../markdown-it/bin/markdown-it.js markdown-it )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf md2html )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../markdown/bin/md2html.js md2html )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../mime/cli.js mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf mkdirp )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../mkdirp/bin/cmd.js mkdirp )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../node-downloader-helper/bin/ndh ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf node-which )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../which/bin/node-which node-which )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf nopt )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../nopt/bin/nopt.js nopt )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf pagexray )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../pagexray/bin/index.js pagexray )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf parser )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../@babel/parser/bin/babel-parser.js parser )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf pixelmatch )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../pixelmatch/bin/pixelmatch pixelmatch )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf resolve )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../resolve/bin/resolve resolve )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../semver/bin/semver.js semver )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf sshpk-conv )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../sshpk/bin/sshpk-conv sshpk-conv )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf sshpk-sign )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../sshpk/bin/sshpk-sign sshpk-sign )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf sshpk-verify )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../sshpk/bin/sshpk-verify sshpk-verify )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf tape )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../tape/bin/tape tape )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf throttle )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../@sitespeed.io/throttle/bin/index.js throttle )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@google-cloud/storage/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@google-cloud/storage/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@sitespeed.io/edgedriver/node_modules/.bin ; rm -rf ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@sitespeed.io/edgedriver/node_modules/.bin ; ln -sf ../node-downloader-helper/bin/ndh ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@sitespeed.io/geckodriver/node_modules/.bin ; rm -rf ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@sitespeed.io/geckodriver/node_modules/.bin ; ln -sf ../node-downloader-helper/bin/ndh ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/aws-sdk/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/aws-sdk/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/chrome-har/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/chrome-har/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/load-bmfont/node_modules/.bin ; rm -rf mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/load-bmfont/node_modules/.bin ; ln -sf ../mime/cli.js mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/request/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/request/node_modules/.bin ; ln -sf ../uuid/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/tape/node_modules/.bin ; rm -rf resolve )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/tape/node_modules/.bin ; ln -sf ../resolve/bin/resolve resolve )

==> sitespeedio-34.11.1-x86_64-1cf.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf sitespeed.io )
( cd usr/bin ; ln -sf ../lib64/node_modules/sitespeed.io/bin/sitespeed.js sitespeed.io )
( cd usr/bin ; rm -rf sitespeed.io-wpr )
( cd usr/bin ; ln -sf ../lib64/node_modules/sitespeed.io/bin/browsertimeWebPageReplay.js sitespeed.io-wpr )
( cd usr/lib64/node_modules/root/node_modules/.bin ; rm -rf network-address )
( cd usr/lib64/node_modules/root/node_modules/.bin ; ln -sf ../network-address/cli.js network-address )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf acorn )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../acorn/bin/acorn acorn )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf adbkit )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../@devicefarmer/adbkit/bin/adbkit adbkit )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf browsertime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../browsertime/bin/browsertime.js browsertime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf btoa )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../btoa/bin/btoa.js btoa )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf chrome-remote-interface )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../chrome-remote-interface/bin/client.js chrome-remote-interface )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf crawl )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../simplecrawler/lib/cli.js crawl )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf fxparser )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../fast-xml-parser/src/cli/cli.js fxparser )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf gp12-pem )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../google-p12-pem/build/src/bin/gp12-pem.js gp12-pem )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf hid-showdevices )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../node-hid/src/show-devices.js hid-showdevices )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf ignored )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../dotignore/bin/ignored ignored )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf markdown-it )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../markdown-it/bin/markdown-it.js markdown-it )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf md2html )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../markdown/bin/md2html.js md2html )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../mime/cli.js mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf mkdirp )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../mkdirp/bin/cmd.js mkdirp )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../node-downloader-helper/bin/ndh ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf node-gyp-build )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../node-gyp-build/bin.js node-gyp-build )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf node-gyp-build-optional )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../node-gyp-build/optional.js node-gyp-build-optional )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf node-gyp-build-test )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../node-gyp-build/build-test.js node-gyp-build-test )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf node-which )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../which/bin/node-which node-which )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf nopt )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../nopt/bin/nopt.js nopt )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf pagexray )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../pagexray/bin/index.js pagexray )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf parser )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../@babel/parser/bin/babel-parser.js parser )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf pixelmatch )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../pixelmatch/bin/pixelmatch pixelmatch )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf pkg-prebuilds-copy )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../pkg-prebuilds/bin/copy.mjs pkg-prebuilds-copy )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf pkg-prebuilds-verify )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../pkg-prebuilds/bin/verify.mjs pkg-prebuilds-verify )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf resolve )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../resolve/bin/resolve resolve )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../semver/bin/semver.js semver )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf sshpk-conv )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../sshpk/bin/sshpk-conv sshpk-conv )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf sshpk-sign )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../sshpk/bin/sshpk-sign sshpk-sign )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf sshpk-verify )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../sshpk/bin/sshpk-verify sshpk-verify )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf static )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../node-static/bin/cli.js static )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf tape )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../tape/bin/tape tape )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf throttle )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../@sitespeed.io/throttle/bin/index.js throttle )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@google-cloud/storage/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@google-cloud/storage/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@sitespeed.io/edgedriver/node_modules/.bin ; rm -rf ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@sitespeed.io/edgedriver/node_modules/.bin ; ln -sf ../node-downloader-helper/bin/ndh ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@sitespeed.io/geckodriver/node_modules/.bin ; rm -rf ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@sitespeed.io/geckodriver/node_modules/.bin ; ln -sf ../node-downloader-helper/bin/ndh ndh )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@smithy/middleware-retry/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/@smithy/middleware-retry/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/chrome-har/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/chrome-har/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/load-bmfont/node_modules/.bin ; rm -rf mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/load-bmfont/node_modules/.bin ; ln -sf ../mime/cli.js mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/node-static/node_modules/.bin ; rm -rf mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/node-static/node_modules/.bin ; ln -sf ../mime/cli.js mime )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/request/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/request/node_modules/.bin ; ln -sf ../uuid/bin/uuid uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/tape/node_modules/.bin ; rm -rf resolve )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/tape/node_modules/.bin ; ln -sf ../resolve/bin/resolve resolve )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/teeny-request/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/sitespeed.io/node_modules/teeny-request/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
